=====
chime
=====

PyPI hosted Python module for CHIME

Documentation
-------------

* `User Documentation <https://code-for-philly.gitbook.io/chime/>`_
* `Developer Documentation <https://codeforphilly.github.io/chime/>`_

Contributing
---------------

* `Contribution Overview <https://codeforphilly.github.io/chime/CONTRIBUTING.html>`_

Join our `Code For Philly <https://codeforphilly.org/>`_ project or our `Slack workspace <https://codeforphilly.org/chat>`_ in the `#covid19-chime-penn <https://codeforphilly.org/chat/covid19-chime-penn>`_ channel if you'd like to chat with us. We'd appreciate your `feedback <http://predictivehealthcare.pennmedicine.org/contact/>`_.

Thanks
------

* Created by `Predictive Healthcare @ Penn Medicine <http://predictivehealthcare.pennmedicine.org/>`_
* Project management provided by `Code for Philly <https://codeforphilly.org/>`_
* Production hosting provided by `Linode Kubernetes Engine <https://www.linode.com/products/kubernetes/>`_
